# Terminal Fun

This project invloves the usage of terminal commands to produces beautiful outputs

## Installation

Run the following to install:

```python
pip install terminal-fun
```

## Usage

```python
from terminalfun import *
cowsay()
```

## Developing terminal-fun

To install terminal-fun along with the tools you need to develop and run tests, run the following command:

```bash
pip install -e .[dev]
```